==> tuia-advert-center-api-2.2.74-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertsCheckRecordDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.util.Date;

/**
 * Created by huangch on 2017/8/23 11:40
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertsCheckRecordDto extends BaseDto {

    private static final long serialVersionUID = -5415165648986002824L;

    /**
     * 广告ID.
     */
    private Long advertId;

    //广告名称
    private String resourceName;

    /**
     * 审核动作类型,1-审核通过;2-审核拒绝;
     */
    private Integer checkType;

    /**
     * 拒绝或冻结理由.
     */
    private String reason;

    /**
     * 广告顾问.
     */
    private String checker;

    /**
     * 广告顾问联系方式.
     */
    private String checkerContact;

    /**
     * 审核人
     */
    private String reviewer;
    /**
     * 素材审核记录数量
     */
    private Integer checkRecord;
    /**
     * 落地页截图url
     */
    private String imageUrl;

    /**
     * 图片P哈希值 用于比较图片差异
     */
    private String hashDegree;
    //广告推广链接
    private String promoteUrl;
    /**
     * 是否复审:0 否 1 是
     */
    private Integer reviewed;
    /** 审核时长(s)*/
    private Long checkLoadTime;
    /** 进审时间. */
    private Date enterCheckTime;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getChecker() {
        return checker;
    }

    public void setChecker(String checker) {
        this.checker = checker;
    }

    public String getCheckerContact() {
        return checkerContact;
    }

    public void setCheckerContact(String checkerContact) {
        this.checkerContact = checkerContact;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public Integer getCheckRecord() {
        return checkRecord;
    }

    public void setCheckRecord(Integer checkRecord) {
        this.checkRecord = checkRecord;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getHashDegree() {
        return hashDegree;
    }

    public void setHashDegree(String hashDegree) {
        this.hashDegree = hashDegree;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Integer getReviewed() {
        return reviewed;
    }

    public void setReviewed(Integer reviewed) {
        this.reviewed = reviewed;
    }

    public Long getCheckLoadTime() {
        return checkLoadTime;
    }

    public void setCheckLoadTime(Long checkLoadTime) {
        this.checkLoadTime = checkLoadTime;
    }

    public Date getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(Date enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }
}

==> tuia-advert-center-api-2.3.32-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertsCheckRecordDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.util.Date;

/**
 * Created by huangch on 2017/8/23 11:40
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertsCheckRecordDto extends BaseDto {

    private static final long serialVersionUID = -5415165648986002824L;

    /**
     * 广告ID.
     */
    private Long advertId;

    //广告名称
    private String resourceName;

    /**
     * 审核动作类型,1-审核通过;2-审核拒绝;
     */
    private Integer checkType;

    /**
     * 拒绝或冻结理由.
     */
    private String reason;

    /**
     * 广告顾问.
     */
    private String checker;

    /**
     * 广告顾问联系方式.
     */
    private String checkerContact;

    /**
     * 审核人
     */
    private String reviewer;
    /**
     * 素材审核记录数量
     */
    private Integer checkRecord;
    /**
     * 落地页截图url
     */
    private String imageUrl;

    /**
     * 图片P哈希值 用于比较图片差异
     */
    private String hashDegree;
    //广告推广链接
    private String promoteUrl;
    /**
     * 是否复审:0 否 1 是
     */
    private Integer reviewed;
    /** 审核时长(s)*/
    private Long checkLoadTime;
    /** 进审时间. */
    private Date enterCheckTime;

    /** 富文本内容*/
    private String context;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getChecker() {
        return checker;
    }

    public void setChecker(String checker) {
        this.checker = checker;
    }

    public String getCheckerContact() {
        return checkerContact;
    }

    public void setCheckerContact(String checkerContact) {
        this.checkerContact = checkerContact;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public Integer getCheckRecord() {
        return checkRecord;
    }

    public void setCheckRecord(Integer checkRecord) {
        this.checkRecord = checkRecord;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getHashDegree() {
        return hashDegree;
    }

    public void setHashDegree(String hashDegree) {
        this.hashDegree = hashDegree;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Integer getReviewed() {
        return reviewed;
    }

    public void setReviewed(Integer reviewed) {
        this.reviewed = reviewed;
    }

    public Long getCheckLoadTime() {
        return checkLoadTime;
    }

    public void setCheckLoadTime(Long checkLoadTime) {
        this.checkLoadTime = checkLoadTime;
    }

    public Date getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(Date enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getContext() {
        return context;
    }

    public void setContext(String context) {
        this.context = context;
    }
}
